Clazz.declarePackage("J.adapter.smarter");
(function(){
var c$ = Clazz.decorateAsClass(function(){
this.atomSetIndex = 0;
Clazz.instantialize(this, arguments);}, J.adapter.smarter, "AtomSetObject", null);
})();
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
